@@ -25,8 +25,8 @@
 namespace MDFN_IEN_PSX
 {
 
-InputDevice *Device_DualAnalog_Create(bool joystick_mode);
-extern IDIISG Device_DualAnalog_IDII;
-extern IDIISG Device_AnalogJoy_IDII;
+InputDevice *Device_DualAnalog_Create(bool joystick_mode) MDFN_COLD;
+MDFN_HIDE extern IDIISG Device_DualAnalog_IDII;
+MDFN_HIDE extern IDIISG Device_AnalogJoy_IDII;
 }
 #endif
